/**
 * Attribute denoting (hierarchical) relation, in the "upwards" direction. For example, a file `IN` a group, an image `IN` photos, etc.
 */
export const ATTR_IN = "IN";

/**
 * Attribute denoting that an entry belongs to the set relating to a given (hierarchical) relation.
 * For example, a data blob may have a label entry, and to qualify that label within the context of belonging to a given hierarchical group, that label entry and the hierarchical entry will be linked with `BY`.
 */
export const ATTR_BY = "BY";

/**
 * Attribute denoting that an attribute belongs to a given "tagging" entity. If an entity belongs to (`IN`) a "tagging" entity, it is expected to have attributes that are `OF` that entity.
 */
export const ATTR_OF = "OF";

/**
 * Attribute denoting a human readable label.
 */
export const ATTR_LABEL = "LBL";

/**
 * Attribute denoting the date & time an entity was noted in the database.
 * (TODO: This info can be trivially derived from existing entry timestamps, while at the same time the "Introduction problem" is still open.)
 */
export const ATTR_ADDED = "ADDED";

/**
 * Attribute for cross-vault unambiguous referencing of non-hashable (e.g. UUID) entities.
 */
export const ATTR_KEY = "KEY";

/**
 * Address of the root hierarchical entry.
 */
export const HIER_ROOT_ADDR =
  "zb2rhmpmTFPxdhaxTQg5Ug3KHFU8DZNUPh8TaPY2v8UQVJbQk";
