import type { PutInput } from '@upnd/upend/types';
import { query as queryFn } from '$lib/entity';
import api from '$lib/api';
import { ATTR_LABEL } from '@upnd/upend/constants';
import type { ApiFetchOptions } from '@upnd/upend/api';

export function baseSearch(query: string, options?: ApiFetchOptions) {
	return queryFn(
		`(or (matches (contains "${query}") ?  ?) (matches ? (contains "${query}") ?) (matches ? ? (contains "${query}")))`,
		options
	);
}

export function baseSearchOnce(query: string, options?: ApiFetchOptions) {
	return api.query(
		`(or (matches (contains "${query}") ?  ?) (matches ? (contains "${query}") ?) (matches ? ? (contains "${query}")))`,
		options
	);
}

export async function createLabelled(label: string, options?: ApiFetchOptions) {
	let body: PutInput;
	if (label.match('^[\\w]+://[\\w]')) {
		body = {
			entity: {
				t: 'Url',
				c: label
			}
		};
		const [_, entity] = await api.putEntry(body);
		return entity;
	} else {
		const [_, entity] = await api.putEntry({
			entity: {
				t: 'Uuid'
			}
		});

		await api.putEntityAttribute(entity, ATTR_LABEL, { t: 'String', c: label }, undefined, options);

		return entity;
	}
}
